function [tobs,y,R] = gen_obs(t,x_t,factor_t2o,H,var_obs)
% [tobs,y,R] = gen_obs(t,x_t,factor_t2o,H)
% this function generates [linear] observations from the truth
% Input:    - t, the time array of the truth
%           - x_t, the true run
%           - factor_t2o, observation frequency (in model t steps)
%           - H, the observation matrix
%           - var_obs, the observational error variance (diagonal R)
% Output:   - tobs, the time array of the observations
%           - y, the observations
%           - R, the observational error covariance matrix

% some settings
tstep_truth = t(2)-t(1);
tstep_obs = factor_t2o*tstep_truth;

[L,N] = size(H);

% the time array for obs (and coincides with the assimilation window time)
tobs=(0:tstep_obs:max(t))';

% initialize observations array
y = NaN(length(tobs),L);

% and covariance
R = var_obs*eye(L,L);

% generate obs
for j=2:length(tobs) % at time 0 there are no obs
 x_aux = x_t(factor_t2o*(j-1)+1,:)';
 eps_aux = sqrt(R)*randn(L,1);
 y_aux = H*x_aux + eps_aux;
 y(j,:) = y_aux';
end




